<?php
if (!function_exists('newscastle_get_option')) :
    /**
     * Get customizer value by key.
     *
     * @param string $key Option key.
     * @return mixed Option value.
     * @since 1.0.0
     *
     */
    function newscastle_get_option($key)
    {
        $key_value = '';
        if (!$key) {
            return $key_value;
        }
        $default_values = newscastle_get_all_customizer_default_values();
        $customizer_values = get_theme_mod('newscastle_options');
        $customizer_values = wp_parse_args($customizer_values, $default_values);

        $key_value = (isset($customizer_values[$key])) ? $customizer_values[$key] : '';
        return $key_value;
    }
endif;


if ( ! function_exists( 'newscastle_get_archive_layouts' ) ) :
	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_get_archive_layouts() {
		$options = apply_filters(
			'newscastle_get_archive_layouts',
			array(
				'archive_style_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-1.webp',
					'label' => esc_html__( 'Archive List View', 'newscastle' ),
				),
				'archive_style_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-2.webp',
					'label' => esc_html__( 'Archive Grid View', 'newscastle' ),
				),
				'archive_style_3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-3.webp',
					'label' => esc_html__( 'Archive Alternate Grid View', 'newscastle' ),
				),
			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'newscastle_get_date_formats' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_get_date_formats() {
		$options = apply_filters(
			'newscastle_archive_date_format',
			array(
				'classic'   => __( 'Classic', 'newscastle' ),
				'time_ago' => __( 'Time Ago', 'newscastle' ),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'newscastle_line_limit_choices' ) ) :
	/**
	 * Returns title limit options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_line_limit_choices() {
		$options = apply_filters(
			'newscastle_title_limit_options',
			array(
				''              => __( '&mdash; No Limit &mdash;', 'newscastle' ),
				'limit-line-1' => __( '1 Line', 'newscastle' ),
				'limit-line-2' => __( '2 Lines', 'newscastle' ),
				'limit-line-3' => __( '3 Lines', 'newscastle' ),
				'limit-line-4' => __( '4 Lines', 'newscastle' ),
				'limit-line-5' => __( '5 Lines', 'newscastle' ),
			)
		);
		return $options;
	}
endif;
if ( ! function_exists( 'newscastle_archive_category_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_archive_category_style() {
		$options = apply_filters(
			'newscastle_archive_category_style',
			array(
				'archive_cat_style_1'   => __( 'Category Style 1', 'newscastle' ),
				'archive_cat_style_2'   => __( 'Category Style 2', 'newscastle' ),
				'archive_cat_style_3'   => __( 'Category Style 3', 'newscastle' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'newscastle_archive_read_time_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_archive_read_time_style() {
		$options = apply_filters(
			'newscastle_archive_read_time_style',
			array(
				'archive_read_time_style_1'   => __( 'Read Time Style 1', 'newscastle' ),
				'archive_read_time_style_2'   => __( 'Read Time Style 2', 'newscastle' ),
				'archive_read_time_style_3'   => __( 'Read Time Style 3', 'newscastle' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'newscastle_get_header_layout' ) ) :
	/**
	 * Returns header layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_get_header_layout() {
		$options = apply_filters(
			'newscastle_get_header_layout',
			array(
				'header_style_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/header-1.webp',
					'label' => esc_html__( 'Header Style 1', 'newscastle' ),
				),
				'header_style_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/header-2.webp',
					'label' => esc_html__( 'Header Style 2', 'newscastle' ),
				),
                'header_style_3' => array(
                    'url'   => get_template_directory_uri() . '/assets/images/header-3.webp',
                    'label' => esc_html__( 'Header Style 3', 'newscastle' ),
                ),
			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'newscastle_social_menu_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_social_menu_style() {
		$options = apply_filters(
			'newscastle_social_menu_style',
			array(
				'has-brand-background'   => __( 'Has Brand Background', 'newscastle' ),
				'has-brand-color'   => __( 'Has Brand Color', 'newscastle' ),
				'none'   => __( 'None', 'newscastle' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'newscastle_pagination_style_choice' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_pagination_style_choice() {
		$options = apply_filters(
			'newscastle_pagination_style_choice',
			array(
				'pagination_none'   => __( 'None', 'newscastle' ),
				'pagination_numeric'   => __( 'Numeric', 'newscastle' ),
				'pagination_default'   => __( 'Default(New/Old Post)', 'newscastle' ),
				'pagination_ajax_on_scroll'   => __( 'Load More On Scroll', 'newscastle' ),
				'pagination_ajax_on_click'   => __( 'Load More On Click', 'newscastle' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'newscastle_category_color' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_category_color() {
		$options = apply_filters(
			'newscastle_category_color',
			array(
				'none'   => __( 'None', 'newscastle' ),
				'has-background'   => __( 'Has background', 'newscastle' ),
				'has-text-color'   => __( 'Has text color', 'newscastle' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'newscastle_get_footer_layouts' ) ) :
	/**
	 * Returns footer layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_get_footer_layouts() {
		$options = apply_filters(
			'newscastle_footer_layouts',
			array(
				'footer_layout_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-4.webp',
					'label' => esc_html__( 'Four Columns', 'newscastle' ),
				),
				'footer_layout_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-3.webp',
					'label' => esc_html__( 'Three Columns', 'newscastle' ),
				),
				'footer_layout_3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2.webp',
					'label' => esc_html__( 'Two Columns', 'newscastle' ),
				),
				'footer_layout_4' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2-big-left.webp',
					'label' => esc_html__( 'Two Columns Big Left', 'newscastle' ),
				),
				'footer_layout_5' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-3-big-middle.webp',
					'label' => esc_html__( 'Three Columns Big Middle', 'newscastle' ),
				),
				'footer_layout_6' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2-big-right.webp',
					'label' => esc_html__( 'Two Columns Big Right', 'newscastle' ),
				),
				'footer_layout_7' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-1.webp',
					'label' => esc_html__( 'Single Column', 'newscastle' ),
				),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'newscastle_preloader_style_option' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_preloader_style_option() {
		$options = apply_filters(
			'newscastle_preloader_style_option',
			array(
				'style-1'   => __( 'Style - 1', 'newscastle' ),
				'style-2'   => __( 'Style - 2', 'newscastle' ),
				'style-3'   => __( 'Style - 3', 'newscastle' ),
				'style-4'   => __( 'Style - 4', 'newscastle' ),
				'style-5'   => __( 'Style - 5', 'newscastle' ),
				'style-6'   => __( 'Style - 6', 'newscastle' ),
				'style-7'   => __( 'Style - 7', 'newscastle' ),
				'style-8'   => __( 'Style - 8', 'newscastle' ),
				'style-9'   => __( 'Style - 9', 'newscastle' ),
				'style-10'   => __( 'Style - 10', 'newscastle' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'newscastle_get_recommended_post' ) ) :
	/**
	 * Returns recommended layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_get_recommended_post() {
		$options = apply_filters(
			'newscastle_get_recommended_post',
			array(
				'wpi-post-recommendation-1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-1.webp',
					'label' => esc_html__( 'Recommended List View', 'newscastle' ),
				),
				'wpi-post-recommendation-2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-2.webp',
					'label' => esc_html__( 'Recommended Grid View', 'newscastle' ),
				),
				'wpi-post-recommendation-3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-3.webp',
					'label' => esc_html__( 'Recommended Alternate Grid View', 'newscastle' ),
				),
			)
		);
		return $options;
	}
endif;



if ( ! function_exists( 'newscastle_author_meta' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_author_meta() {
		$options = apply_filters(
			'newscastle_author_meta',
			array(
				'with_label'   => __( 'With Label', 'newscastle' ),
				'with_icon'   => __( 'With Icon', 'newscastle' ),
				'with_avatar_image'   => __( 'With Avatar Image', 'newscastle' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'newscastle_date_meta' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_date_meta() {
		$options = apply_filters(
			'newscastle_date_meta',
			array(
				'with_label'   => __( 'With Label', 'newscastle' ),
				'with_icon'   => __( 'With Icon', 'newscastle' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'newscastle_get_sidebar_layouts' ) ) :
	/**
	 * Returns general layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_get_sidebar_layouts() {
		$options = apply_filters(
			'newscastle_sidebar_layouts',
			array(
				'left-sidebar'      => array(
					'url'   => get_template_directory_uri() . '/assets/images/left-sidebar.webp',
					'label' => esc_html__( 'Left Sidebar', 'newscastle' ),
				),
				'right-sidebar'     => array(
					'url'   => get_template_directory_uri() . '/assets/images/right-sidebar.webp',
					'label' => esc_html__( 'Right Sidebar', 'newscastle' ),
				),
				'no-sidebar'        => array(
					'url'   => get_template_directory_uri() . '/assets/images/no-sidebar.webp',
					'label' => esc_html__( 'No Sidebar - Wide', 'newscastle' ),
				),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'newscastle_get_social_links_styles' ) ) :
	/**
	 * Returns social links styles options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function newscastle_get_social_links_styles() {
		$options = apply_filters(
			'newscastle_social_links_styles',
			array(
				'style_1' => __( 'Style 1', 'newscastle' ),
				'style_2' => __( 'Style 2', 'newscastle' ),
				'style_3' => __( 'Style 3', 'newscastle' ),
				'style_4' => __( 'Style 4', 'newscastle' ),
			)
		);
		return $options;
	}
endif;
